#
# spec file for package libbytesize
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define somajor 1
%define libname %{name}%{somajor}
Name:           libbytesize
VCS: https://src.suse.de/pool/libbytesize#8a1d2e899f2cb69ccb93b161e1ef1d69d191a7de
Version:        2.8
Release:        1.9
Summary:        A library for working with sizes in bytes
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/storaged-project/libbytesize
Source:         https://github.com/storaged-project/libbytesize/releases/download/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc-build
BuildRequires:  gmp-devel
BuildRequires:  gtk-doc
BuildRequires:  mpfr-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(libpcre2-8)

%description
The LibBytesize is a C library that facilitates work with sizes in
bytes, be it parsing the input from users or producing a human-readable
representation of a size in bytes. This library takes localization into
account. It also provides support for sizes bigger than MAXUINT64.

%package -n %{libname}
Summary:        A library for working with sizes in bytes
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n %{libname}
The LibBytesize is a C library that facilitates work with sizes in
bytes, be it parsing the input from users or producing a human-readable
representation of a size in bytes. This library takes localization into
account. It also provides support for sizes bigger than MAXUINT64.

%package -n bscalc
Summary:        A utility for working with sizes in bytes
Group:          System/Libraries
Requires:       %{libname} = %{version}
BuildArch:      noarch

%description -n bscalc
The LibBytesize is a C library that facilitates work with sizes in
bytes, be it parsing the input from users or producing a human-readable
representation of a size in bytes. This library takes localization into
account. It also provides support for sizes bigger than MAXUINT64.

%package devel
Summary:        Development files for LibBytesize
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
This package contains header files and pkg-config files needed for development
with the LibBytesize library.

%package -n python3-%{name}
Summary:        Python 3 bindings for LibBytesize
Group:          Development/Libraries/Python
Requires:       %{libname} = %{version}
Requires:       python3-six

%description -n python3-%{name}
This package contains Python 3 bindings for LibBytesize making the use of
the library from Python 3 easier and more convenient.

%lang_package

%prep
%autosetup

%build
%configure \
    --disable-static \
    --with-python3 \
    --with-gtk-doc
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n bscalc
%license LICENSE
%doc README.md
%{_bindir}/bscalc
%{_mandir}/man1/bscalc.1*

%files -n %{libname}
%{_libdir}/%{name}.so.*

%files devel
%doc %{_datadir}/gtk-doc/html/%{name}
%{_libdir}/%{name}.so
%dir %{_includedir}/bytesize
%{_includedir}/bytesize/bs_size.h
%{_libdir}/pkgconfig/bytesize.pc

%files -n python3-%{name}
%dir %{python3_sitearch}/bytesize
%{python3_sitearch}/bytesize/*

%files lang -f %{name}.lang

%changelog
* Sat May  6 2023 luc14n0@opensuse.org
- Drop lang sub-package recommendation. It's not needed anymore now
  that lang packages provide package supplementation instead.
- Make bscalc sub-package 'noarch', since it doesn't contain any
  binaries, only a Python script and its manpage.
* Thu May  4 2023 dmueller@suse.com
- update to 2.8:
  * Added translation using Weblate
  * configure.ac: Remove invalid email address for bug reports
  * spec: Bump release to 21 for Packit daily builds
  * spec: Fix source archive URL
  * Make use of error optional
  * Replace C++ style comments with C style
  * Various docstring fixes
  * docs: Remove information about Python 2 support
  * Remove unused test dependencies variables from Makefile
  * Do not hardcode pylint executable name in Makefile
* Thu Jul 14 2022 dmueller@suse.com
- update to 2.7:
  * Fix skipping tests when required locale is missing
  * Remove Travis CI configuration
  * Fix some warnings and typos in docstrings and comments
  * Fix warnings dicovered by the GCC analyzer
  * build: avoid bashisms in configure
  * Update translation files
  * Do not use distutils to get Python library path
* Sat Jul 17 2021 dmueller@suse.com
- update to 2.6:
  * Make sure Size can be interpreted as integer in Python 3.10
  * Translation updates
* Sat Jan 30 2021 dmueller@suse.com
- update to 2.5:
  * translation updates
  * tools: Read input from stdin when not running in a tty
  * Add support to ppc64le for debian build
  * testsuite fixes
* Sun Aug 16 2020 dmueller@suse.com
- update to 2.4:
  * remove msgcat dependency
  * Translated using Weblate (Bengali (India))
  * Add Travis build status badge
  * Update translation files
  * add translation platform widget
  * Translated using Weblate (Turkish)
  * Fix memory leak in bs_size_new_from_str
  * Update translation files
  * src/gettext: fix warning if gettext is already present
  * fix build on shells where test == fails
  * Require the same version of python3-bytesize in libbytesize-tools
  * New minor release of the libbytesize library. There are only two bugfixes in this release.
  * Full list of changes
  * fix out of tree build failure
  * Fix return value for round_to_nearest when using Size
  * New bytesize calculator bssize has been added.
  * Code has been ported from PCRE to PCRE2.
  * Python 2 support has been removed.
  * Run all libbytesize tests from one script
  * Add all "public" python API symbols to __init__.py
  * Allow running tests using installed library
  * Remove Python 2 support
  * Port to pcre2
  * Add support for floor division by a non-integer number in Python
  * Add a simple bytesize calculator tool
  * Add tools to autotools and packaging
  * Exit with 1 from configure if there were failures
  * Add a summary to the end of ./configure output
  * Only support modulo between two Size instances
  * Fix parsing of exponential representations of real numbers
  * Add the '--version' option to bs_calc.py
  * Add a man page for the bscalc tool
  * Assume the given expression is in bytes if no unit is given
* Mon Nov 19 2018 luc14n0@linuxmail.org
- Update to version 1.4:
  + There are only small changes in this release.
* Fri May  4 2018 luc14n0@linuxmail.org
- Update to version 1.3:
  + Do not segfault when trying to bs_size_free NULL.
- Cleanup specfile removing deprecations.
- Update LGPL License tag appending '-only' to comply with SPDX
  3.0.
- Add gcc BuildRequires to avoid implicit dependencies.
* Tue Feb  6 2018 luc14n0@linuxmail.org
- Add a %%{name}-lang Recommends tag in the preamble and a %%{name}
  Provides tag under the lib subpackage so the lang subpackge can
  be installable.
* Mon Feb  5 2018 jengelh@inai.de
- Clear up unusual grammar in description.
- Replace %%__-type macro indirections by their normal variants.
* Tue Nov 28 2017 luc14n0@linuxmail.org
- Initial package, version 1.2.
